body {
    font: normal 11px auto Verdana, Arial, Helvetica, sans-serif;
    color: #4f6b72;
    background: #E6EAE9;
}

a { color: #c75f3e; }

a:hover {
    background-color: #c75f3e;
    color: #FFF;
}

/*
#books {
    width: 700px;
    padding: 0;
    margin: 0;
}
*/

label {
    float: left;
    width: 70px;
}

.title {
    text-transform: uppercase;
    text-decoration: underline;
}

ul { padding: 0; }

li {
    display: inline;
    font: bold 11px Verdana, Arial, Helvetica, sans-serif;
    color: #4f6b72;
    border: 1px solid #C1DAD7;
    letter-spacing: 2px;
    text-transform: uppercase;
    padding: 6px 6px 6px 12px;
    background-color: #FFF;
}

.section { display: }

caption {
    padding: 0 0 5px 0;
    width: 700px;
    font: italic 11px Verdana, Arial, Helvetica, sans-serif;
    text-align: left;
}

th {
    font: bold 11px Verdana, Arial, Helvetica, sans-serif;
    color: #4f6b72;
    border-right: 1px solid #C1DAD7;
    border-bottom: 1px solid #C1DAD7;
    border-top: 1px solid #C1DAD7;
    letter-spacing: 2px;
    text-transform: uppercase;
    text-align: left;
    padding: 6px 6px 6px 12px;
    background: #CAE8EA url(header_bg.jpg) no-repeat;
}

th.nobg {
    border-top: 0;
    border-left: 0;
    border-right: 1px solid #C1DAD7;
    background: none;
}

td {
    border-right: 1px solid #C1DAD7;
    border-bottom: 1px solid #C1DAD7;
    padding: 6px 6px 6px 12px;
    color: #4f6b72;
}

tr {
    background-color: #D2EBEB;
    color: #797268;
}

tr.alt {
    background: #FFF;
    color: #797268;
}

th.spec {
    border-left: 1px solid #C1DAD7;
    border-top: 0;
    background: #FFF;
    font: bold 10px Verdana, Arial, Helvetica, sans-serif;
}

th.specalt {
    border-left: 1px solid #C1DAD7;
    border-top: 0;
    background-color: #f5fafa;
    font: bold 10px Verdana, Arial, Helvetica, sans-serif;
    color: #797268;
}

.error {
    font: bold 14px Verdana, Arial, Helvetica, sans-serif;
    font-size: 2em;
    color: #4f6b72;
    border: 1px solid: #797268
 }

.big { font-weight:bold; font-size: 16px; }
